@@ -91,7 +91,7 @@ class Hermes:
 
     self.gc.set_string('/apps/maemo/hermes/session_key', session['session_key'])
     self.gc.set_string('/apps/maemo/hermes/secret_key', session['secret'])
-    self.gc.set_int('/apps/maemo/hermes/uid', session['uid'])
+    self.gc.set_string('/apps/maemo/hermes/uid', session['uid'])
 
 
   # -----------------------------------------------------------------------
@@ -111,7 +111,7 @@ class Hermes:
       if self.fb.session_key is None:
         self.fb.session_key = self.gc.get_string('/apps/maemo/hermes/session_key')
         self.fb.secret = self.gc.get_string('/apps/maemo/hermes/secret_key')
-        self.fb.uid = self.gc.get_int('/apps/maemo/hermes/uid')
+        self.fb.uid = self.gc.get_string('/apps/maemo/hermes/uid')
 
       # Check the available session is still valid...
       while True:
